<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>About</name>
    <message>
        <location filename="../src/about.ui" line="26"/>
        <location filename="../src/about.cpp" line="37"/>
        <source>About</source>
        <translation>Environ</translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="82"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:700;&quot;&gt;UltimateDailyWallpaper&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="89"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Version: &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="133"/>
        <source>tab0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="178"/>
        <source>label_4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="191"/>
        <source>label_5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="204"/>
        <source>label_6</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="230"/>
        <source>tab1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="257"/>
        <source>TextLabel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="316"/>
        <source>pushButton_3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="335"/>
        <source>pushButton</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="38"/>
        <source>Currently used plugin</source>
        <translation>Plugin actuellement utilisé</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="44"/>
        <source>License: GPL-3.0+</source>
        <translation>License: GPL-3.0+</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="48"/>
        <source>Version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="54"/>
        <source>Patrice Coni</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="56"/>
        <source>Copyright © 2022 - </source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="62"/>
        <source>A wallpaper changer</source>
        <translation>Une application pour changer le fond d’écran</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="64"/>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="65"/>
        <source>Visit website</source>
        <translation>Visiter le site web</translation>
    </message>
    <message>
        <source>A simple application for changing wallpaper</source>
        <translation type="vanished">Une application simple pour changer de fond d’écran</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.cpp" line="93"/>
        <source>No connection to the internet.
The application will be closed.</source>
        <translation>Pas de connexion à Internet. 
L&apos;application sera fermée.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="119"/>
        <source>Reset</source>
        <translation>Réinitialisation</translation>
    </message>
    <message>
        <source>The folder that containing the plugins was not found. Do you want to set the folder manually?</source>
        <translation type="vanished">Le dossier contenant les plugins est introuvable. Voulez-vous définir le dossier manuellement ?</translation>
    </message>
    <message>
        <source>Select directory</source>
        <translation type="obsolete">Sélectionner un répertoire</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="119"/>
        <source>The folder containing the plugins was not found. Do you want to set the folder manually?</source>
        <translation>Le dossier contenant les plugins est introuvable. Voulez-vous le définir manuellement&#xa0;?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="125"/>
        <source>Select Plugin Folder</source>
        <translation>Sélectionner le dossier des plugins</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="134"/>
        <source>No Plugins Found</source>
        <translation>Aucun plugin trouvé</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="135"/>
        <source>The folder does not contain any plugin files (*.so). Please choose a valid plugin folder.</source>
        <translation>Ce dossier ne contient aucun fichier de plugin (*.so). Veuillez choisir un dossier de plugin valide.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="323"/>
        <location filename="../src/mainwindow.cpp" line="334"/>
        <location filename="../src/mainwindow.cpp" line="811"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="323"/>
        <source>No plugins found.</source>
        <translation>Aucun plugin trouvé.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="329"/>
        <location filename="../src/mainwindow.cpp" line="806"/>
        <source>done.</source>
        <translation>fait.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="330"/>
        <location filename="../src/mainwindow.cpp" line="807"/>
        <source>Used plugin: </source>
        <translation>Plugin utilisé: </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="334"/>
        <location filename="../src/mainwindow.cpp" line="811"/>
        <source>Error while loading plugin.</source>
        <translation>Erreur lors du chargement du plugin.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="424"/>
        <source>An error was detected when starting the application.
The application will be closed.</source>
        <translation>Une erreur a été détectée lors du démarrage de l’application.
La demande sera fermée.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="493"/>
        <source>No connection to the internet.</source>
        <translation>Pas de connexion à Internet.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="493"/>
        <source>Please check your internet connection.</source>
        <translation>Veuillez vérifier votre connexion Internet.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="796"/>
        <source>&amp;Provider</source>
        <translation>&amp;Fournisseur</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="834"/>
        <source>&amp;About this picture and license</source>
        <translation>&amp;À propos de cette image et licence</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="838"/>
        <source>&amp;About this picture and copyright</source>
        <translation>&amp;À propos de cette image et copyright</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="845"/>
        <source>&amp;Download past pictures</source>
        <translation>&amp;Télécharger les photos passées</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="849"/>
        <source>&amp;Load stored picture</source>
        <translation>&amp;Charger l’image stockée</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="852"/>
        <source>&amp;Settings</source>
        <translation>&amp;Paramètres</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="855"/>
        <source>&amp;About</source>
        <translation>&amp;Environ</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="858"/>
        <source>&amp;Quit</source>
        <translation>&amp;Finir</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="873"/>
        <source>No internet connection.</source>
        <translation>Pas de connexion internet.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="932"/>
        <source>Description: 
</source>
        <translation>Description: 
</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1256"/>
        <source>Offline</source>
        <translation>Offline</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1257"/>
        <source>No internet connection available.</source>
        <translation>Pas de connexion internet.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1518"/>
        <source>Load plugin...</source>
        <translation>Charger le plugin...</translation>
    </message>
</context>
<context>
    <name>PhotoBrowser</name>
    <message>
        <location filename="../src/photobrowser.ui" line="20"/>
        <location filename="../src/photobrowser.ui" line="58"/>
        <source>Load stored picture</source>
        <translation>Charger l’image stockée</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.ui" line="90"/>
        <location filename="../src/photobrowser.ui" line="187"/>
        <source>&amp;Set as wallpaper</source>
        <translation>&amp;Définir comme fond d’écran</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.ui" line="174"/>
        <source>Select a photo</source>
        <translation>Sélectionnez une photo</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.ui" line="282"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Select date: &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Sélectionnez la date: &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.ui" line="325"/>
        <source>&amp;Set current date</source>
        <translation>&amp;Définir la date actuelle</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.ui" line="382"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Show photos of past days: &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Afficher les photos des jours passés: &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.ui" line="449"/>
        <source>&amp;Show pictures</source>
        <translation>&amp;Afficher les photos</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="209"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="209"/>
        <source>Error while loading plugin.</source>
        <translation>Erreur lors du chargement du plugin.</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="214"/>
        <source>Past pictures of the day (Wikimedia Commons)</source>
        <translation>Photos passées de la journée (Wikimedia Commons)</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="263"/>
        <source>Get more information</source>
        <translation>Obtenir plus d’informations</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="430"/>
        <source>Details</source>
        <translation>Détails</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="434"/>
        <source>Please select a picture.</source>
        <translation>Veuillez sélectionner une image.</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="442"/>
        <source>Title: </source>
        <translation>Titre: </translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="448"/>
        <source>Description: </source>
        <translation>Description: </translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="460"/>
        <source>Picture size:</source>
        <translation>Taille de l’image:</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="470"/>
        <source>Preview:</source>
        <translation>Aperçu:</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="508"/>
        <source>Download in progress...</source>
        <translation>Téléchargement en cours...</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="551"/>
        <source>The entered date must not be in the future.</source>
        <translation>La date saisie ne doit pas être dans le futur.</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="641"/>
        <source>Working in progress...</source>
        <translation>Travaux en cours...</translation>
    </message>
</context>
<context>
    <name>QProgressDialog</name>
    <message>
        <source>Download in progress...</source>
        <translation type="vanished">Téléchargement en cours...</translation>
    </message>
    <message>
        <source>Working in progress...</source>
        <translation type="vanished">Travaux en cours...</translation>
    </message>
</context>
<context>
    <name>SettingsWindow</name>
    <message>
        <location filename="../src/settingswindow.ui" line="23"/>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="37"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Location to save background photos: &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Emplacement pour enregistrer les photos d’arrière-plan: &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="55"/>
        <source>Choose</source>
        <translation>Choisir</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="72"/>
        <source>Delete wallpapers older than (days): </source>
        <translation>Supprimer les fonds d’écran plus anciens que (jours): </translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="121"/>
        <source>Change desktop background photo automatically</source>
        <translation>Modifier automatiquement la photo d’arrière-plan du Bureau</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="141"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Time of day for changing wallpaper automatically: &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Heure de la journée pour changer automatiquement le fond d’écran: &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="181"/>
        <source>Run Application at startup</source>
        <translation>Exécuter l’application au démarrage</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="198"/>
        <source>Change lock screen wallpaper if possible</source>
        <translation>Changer le fond d’écran de l’écran de verrouillage si possible</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="240"/>
        <location filename="../src/settingswindow.cpp" line="176"/>
        <source>Reset</source>
        <translation>Réinitialisation</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="272"/>
        <source>Save settings</source>
        <translation>Sauvegarder</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="291"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.cpp" line="141"/>
        <source>Save changes</source>
        <translation>Sauvegarder</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.cpp" line="141"/>
        <source>The application will be restart for the changes to take effect. Do you want save the changes?</source>
        <translation>L’application sera redémarrée pour que les modifications prennent effet. Voulez-vous enregistrer les modifications ?</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.cpp" line="155"/>
        <source>Select directory</source>
        <translation>Sélectionner un répertoire</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.cpp" line="176"/>
        <source>This will reset all settings to the default settings. All existing wallpapers will be deleted. Do you want to continue?</source>
        <translation>Cela réinitialisera tous les paramètres aux paramètres par défaut. Tous les fonds d’écran existants seront supprimés. Voulez-vous continuer?</translation>
    </message>
</context>
<context>
    <name>setWallpaper</name>
    <message>
        <location filename="../src/setwallpaper.cpp" line="207"/>
        <source>Error: Failed to set wallpaper on macOS.</source>
        <translation>Erreur - Impossible de définir le papier peint.</translation>
    </message>
    <message>
        <location filename="../src/setwallpaper.cpp" line="218"/>
        <source>Error - Failed to set wallpaper.</source>
        <translation>Erreur - Impossible de définir le papier peint.</translation>
    </message>
</context>
</TS>
